# Author: Ashesh Rambachan <asheshr@g.harvard.edu>
# Description:
#   This script cleans the experimental results from 
#   Andreoni & Samuelson (2006). This script is called
#   by andreoni-samuelson_analysis.R.

# Part 1: Load & clean Andreoni & Samuelson (2006) data ---------------
# Read in data from each experiment session
session.May1A = readxl::read_excel(here("AndreoniSamuelson-ReplicationData/AndSamDataForPublic.xls"), sheet = "May 1, 02 A") %>%
  select(-c(RUNGROUP, All, DEC, "P-AL", "P_DEC", "Tot_EARN")) %>%
  rename(p2_push = X, decision = "All Dec", 
         partner_decision = "P-ALL Dec", tokens = EARN, 
         dollars = "Payoff$", partner_tokens = "P_EARN", 
         partner_dollars = "P-Payoff$", partner = Partner, 
         game = Game, round = Round, id = ID) 
session.May1A = session.May1A %>%
  mutate(session.id = rep(1, nrow(session.May1A)))

session.May1B = readxl::read_excel(here("AndreoniSamuelson-ReplicationData/AndSamDataForPublic.xls"), sheet = "May 1, 02 B") %>%
  select(-c(RUNGROUP, All, DEC, "P-AL", "P_DEC", "Tot_EARN")) %>%
  rename(p2_push = X, decision = "All Dec", 
         partner_decision = "P-ALL Dec", tokens = EARN, 
         dollars = "Payoff$", partner_tokens = "P_EARN", 
         partner_dollars = "P-Payoff$", partner = Partner, 
         game = Game, round = Round, id = ID) 
session.May1B = session.May1B %>% 
  mutate(session.id = rep(2, nrow(session.May1B)))

session.Oct2 = readxl::read_excel(here("AndreoniSamuelson-ReplicationData/AndSamDataForPublic.xls"), sheet = "Oct 2, 02", range = "A9:K889") %>%
  rename(game = Game, round = Round, id = ID, 
         p2_push = "x value", decision = Decision, 
         partner = Partner, partner_decision = "Part Dec", 
         tokens = "Token Earn", dollars = "Dollars Ear", 
         partner_tokens = "Part Token", partner_dollars = "Part Dollars"
  )
session.Oct2 = session.Oct2 %>%
  mutate(session.id = rep(3, nrow(session.Oct2)))

session.Oct9 = readxl::read_excel(here("AndreoniSamuelson-ReplicationData/AndSamDataForPublic.xls"), sheet = "Oct 9, 02", range = "A9:K890") %>%
  rename(game = Game, round = Round, id = ID, 
         p2_push = "x value", decision = Decision, 
         partner = Partner, partner_decision = "Part Dec", 
         tokens = "Token Earn", dollars = "Dollars Ear", 
         partner_tokens = "Part Token", partner_dollars = "Part Dollars"
  )
session.Oct9 = session.Oct9 %>%
  mutate(session.id = rep(4, nrow(session.Oct9)))
session.Oct9 = unique(session.Oct9) # NOTE: session.Oct9 has a duplicate observation that we remove

session.Oct16 = readxl::read_excel(here("AndreoniSamuelson-ReplicationData/AndSamDataForPublic.xls"), sheet = "Oct 16, 02", range = "A9:K889") %>%
  rename(game = Game, round = Round, id = ID, 
         p2_push = "x value", decision = Decision, 
         partner = Partner, partner_decision = "Part Dec", 
         tokens = "Token Earn", dollars = "Dollars Ear", 
         partner_tokens = "Part Token", partner_dollars = "Part Dollars"
  )
session.Oct16 = session.Oct16 %>%
  mutate(session.id = rep(5, nrow(session.Oct16)))

# Merge data from each experiment into single dataframe
experiment.data = bind_rows(session.May1A, session.May1B, 
                            session.Oct2, session.Oct9,
                            session.Oct16) %>% 
  arrange(session.id, game, id, round)
rm(session.May1A, session.May1B, session.Oct2, session.Oct9, session.Oct16)

# Construct value of lambda, treatment flag and treatment probability
experiment.data = experiment.data %>%
  mutate(x2.value = p2_push/3,
         lambda = x2.value/10,
         Wobs = ifelse(lambda >= 0.6, 1, 0), 
         pT = 5/11)

# Construct observed outcome of total tokens earned
experiment.data = experiment.data %>%
  group_by(session.id, game, id) %>%
  mutate(Yobs = ifelse(substr(decision, start = 1, stop = 4) == "PULL", 1, 0)
  ) %>%
  filter(round == 2) %>% ungroup()

# Construct panel identifier: this is a 2 or 3 digit number, where the first digit equals the session
# and the second two digits equals the user id.
experiment.data = experiment.data %>%
  mutate(unitId = paste(session.id, id, sep = ""), 
         unitId = as.numeric(unitId), 
         partnerId = paste(session.id, partner, sep = ""), 
         partnerId = as.numeric(partnerId),
         upId =  paste(session.id, id, partner, sep = ""),
         upId = as.numeric(upId),
         puId = paste(session.id, partner, id, sep = ""),
         puId = as.numeric(puId)
  )

# Remove unneeded variables
experiment.data = experiment.data %>%
  select(-c(p2_push, decision, partner, partner_decision,
            tokens, dollars, partner_tokens, partner_dollars,
            x2.value, lambda, session.id, 
            id, round))

# Sort data by unitId, game
experiment.data = experiment.data %>% 
  rename(period = game) %>%
  arrange(unitId, period)