# Author: Victoria L. Prince <vliublinska@hbs.edu>
# Description:
# Shell script combines all simulation steps for the one unit, large T simulations: 
# - Expanding parameters values into a table of combinations (param_expand_largeT.R)
# - Running a job array, with one job per combination (simulate_largeT.R)
# - Combining simulation results for all jobs (combine_largeT.R)
#
# We analyze the results offline.

#!/bin/bash
bsub -u asheshr@g.harvard.edu -q short -R "rusage[mem=1000]" -M 1000 -J NExpand Rscript src/param_expand_largeN.R
bwait -w "ended(NExpand)" 2> /dev/null

# Recording the resulting number of parameter combinations
num_comb=$(< data/panel_param_combinations_largeN.csv wc -l)
let num_comb--

# Making sure we do not submit more than 1000 jobs (this condition can be relaxed)
if [ $num_comb -lt 1000 ]
then
  echo Submitting ${num_comb} jobs...
  LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=36000]" -M 36000 -J "Sim[1-$num_comb]" -n 4 -hl Rscript src/simulate_largeN_normal.R
  # LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=36000]" -M 36000 -J "Sim[1-$num_comb]" -n 4 -hl Rscript src/simulate_largeN_cauchy.R
  bwait -w 'ended(Sim)' 2> /dev/null

  rm data/panel_param_combinations_largeN.csv

  echo Summarising simulation results...
  LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=24000]" -M 24000 -J NCombine Rscript src/combine_largeN.R 
  bwait -w 'ended(NCombine)' 2> /dev/null
else
  echo "The number of jobs ${num_comb} is too large. Remove some parameter values."
fi