# Author: Ashesh Rambachan <asheshr@g.harvard.edu>
# Description:
# Shell script combines all simulation steps for the large N, T simulations: 
# - Expanding parameters values into a table of combinations (param_expand_largeNT.R)
# - Running a job array, with one job per combination (simulate_largeNT.R)
# - Combining simulation results for all jobs (combine_largeNT.R)
#
# We analyze the results offline.

#!/bin/bash
bsub -u asheshr@g.harvard.edu -q short -R "rusage[mem=1000]" -M 1000 -J NTExpand Rscript src/param_expand_largeNT.R
bwait -w "ended(NTExpand)" 2> /dev/null

# Recording the resulting number of parameter combinations
num_comb=$(< data/panel_param_combinations_largeNT.csv wc -l)
let num_comb--

# Making sure we do not submit more than 1000 jobs (this condition can be relaxed)
if [ $num_comb -lt 1000 ]
then
  echo Submitting ${num_comb} jobs...
  LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=20000]" -M 20000 -J "Sim[1-$num_comb]" -n 8 -hl Rscript src/simulate_largeNT.R
  bwait -w 'ended(Sim)' 2> /dev/null

  rm data/panel_param_combinations_largeNT.csv

  echo Summarising simulation results...
  LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=48000]" -M 48000 -J NTCombine Rscript src/combine_largeNT.R 
  bwait -w 'ended(NTCombine)' 2> /dev/null
else
  echo "The number of jobs ${num_comb} is too large. Remove some parameter values."
fi