# Author: Victoria L. Prince <vliublinska@hbs.edu>
# Description:
# Shell script combines all simulation steps for the one unit, large T simulations: 
# - Expanding parameters values into a table of combinations (param_expand_largeT.R)
# - Running a job array, with one job per combination (simulate_largeT.R)
# - Combining simulation results for all jobs (combine_largeT.R)
#
# We analyze the results offline.

#!/bin/bash
bsub -u asheshr@g.harvard.edu -q short -R "rusage[mem=1000]" -M 1000 -J TExpand Rscript src/param_expand_largeT.R
bwait -w "ended(TExpand)" 2> /dev/null

# Recording the resulting number of parameter combinations
num_comb=$(< data/panel_param_combinations_largeT.csv wc -l)
let num_comb--

# Making sure we do not submit more than 1000 jobs (this condition can be relaxed)
if [ $num_comb -lt 1000 ]
then
  echo Submitting ${num_comb} jobs...
  LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=8000]" -M 8000 -J "Sim[1-$num_comb]" -n 8 -hl Rscript src/simulate_largeT.R
  bwait -w 'ended(Sim)' 2> /dev/null

  rm data/panel_param_combinations_largeT.csv

  echo Summarising simulation results...
  LSB_JOB_REPORT_MAIL=N bsub -q short -R "rusage[mem=16000]" -M 16000 -J TCombine Rscript src/combine_largeT.R 
  bwait -w 'ended(TCombine)' 2> /dev/null
else
  echo "The number of jobs ${num_comb} is too large. Remove some parameter values."
fi