# Author: Ashesh Rambachan <asheshr@g.harvard.edu>
# Description:
#   The script is used to simulate results for a given combination of input parameters for the large N,T simulations. The combination is taken from
# panel_param_combinations_largeN.csv according to LSB_JOBINDEX row number. It is then processed and results are outputted 
#  into scrap/sim_res[LSB_JOBINDEX]_largeN.rds

source("src/panel_analysis_functions.R")
source("src/panel_simulation_functions.R")

job_index <- as.integer(Sys.getenv("LSB_JOBINDEX"))

Sys.sleep(runif(1)*10)
combination <- read.csv("data/panel_param_combinations_largeNT.csv")[job_index,]

resR.temp <- AR1.panel.gen.multiple_largeNT(sims = combination$numSims, 
                                    timePeriods = combination$timePeriods, 
                                    Nunits = combination$Nunits, 
                                    phi = rep(combination$phi, combination$Nunits), 
                                    beta = rep(combination$beta, combination$Nunits), 
                                    pT = matrix(combination$pT, nrow = combination$Nunits, combination$timePeriods), 
                                    err.dist = combination$err.dist, 
                                    sigma = combination$sigma, 
                                    seed = 1234567890, 
                                    parallel = TRUE)

# Create a temporary directory scrap/ if it doesn't exist
if (!dir.exists("scrap")) {
  dir.create('scrap')
}

path <- paste0("scrap/sim_res", job_index, "_largeNT.rds")
saveRDS(resR.temp, path) 

